extensions[gis csv]

globals [
  ;households
  Ricefarmers Rubberfarmers Illipefarmers  Illipeprocessors
  food-insecure-households
  mean_energyconsumption  mean_riceconsumption  mean_rubberincome mean_rubberAFincome  mean_illipeAFincome  mean_illipeprocessedincome mean_AFincome
  amean_energyconsumption  amean_riceconsumption
  mean_income
  new-plots area_cultivated share-illipe mean_plots_rubber  mean_plots_cultivated  mean_plots_AF  mean_plots_rice
  ;GIS
  rivers  vegetasi danau betung

  ;inputs
  work-for-rice  work-for-tonf work-for-processing  rubbercalories illipecalories
  ricecalories pricerice pricerubber

  ;patches
  illiperubberyieldi  illiperubberyieldr rubberyield yieldfat

  fatshare
  probsecondrice probrubber

  ricepatches riceweedpatches youngfallowpatches  oldfallowpatches secondaryforestpatches  illipepatches rubberpatches   forestpatches
  mean_basal mean_alpha mean_density mean_bird_richness mean_biomass mean_patch_tree_richness
  mean_fertility mean_rice_fertility
  carbon_lost carbon_patch carbon_ha

  ricefactor
]

turtles-own [
  HHID plots_cultivated plots_rice plots_rubber plots_AF Farmsize NumberPlots my-plots fallow-plots
  initial-laborforce available-laborforce
  EnergyRequirement iEnergyRequirement Energyconsumption Riceconsumption Rubberincome IllipeAFincome RubberAFincome AFincome IllipeincomeProcessed  food-insecure  deficit
  aEnergyconsumption aRiceconsumption aRubberincome aIllipeAFincome aRubberAFincome aAFincome aIllipeincomeProcessed income
  RiceFarmer IllipeFarmer RubberFarmer Illipeprocessor Illipeharvest

  ;auxiliary variables
  max-plotid
  ishare-illipe
  iarea_cultivated
]

patches-own [
  owner  plotid
  vegetation class fallowlength fertility yield
  rubber illipe
  patch_alpha patch_basal patch_density bird_richness biomass patch_tree_richness
  river riverprox vegetasipatch  nationalpark
  ;auxiliary variable
  vegetasivali
]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;
to setup
  reset-timer
  clear-globals
  clear-ticks
  clear-turtles
  clear-all-plots
  clear-output
  setup-maps
  print "setup maps check"
  setup-farmers
  print "setup farmers check"
  setup-farms
  print "setup farms check"
  setup-globals
  reset-ticks
  show timer
end
;;;;;;;;;;;;;;;;;;;;;;;;


to setup-maps
  reset-timer
  clear-all
  ;load datasets
  set vegetasi gis:load-dataset "Data/Vegetasi_clip.shp"
  set rivers   gis:load-dataset "Data/Rivers_clip.shp"
  set danau    gis:load-dataset "Data/Danau_Sentarum_NP_Boundary_clip.shp"
  set betung   gis:load-dataset "Data/Betung_Kerihun_NP_Boundary_clip.shp"
  ;create the envelope
  gis:set-world-envelope (gis:envelope-union-of (gis:envelope-of vegetasi) (gis:envelope-of rivers) (gis:envelope-of danau) (gis:envelope-of betung) )
  ;color
  gis:set-drawing-color blue
  gis:draw rivers 1
  gis:set-drawing-color pink
  gis:draw danau 1
  gis:set-drawing-color pink
  gis:draw betung 1

  foreach gis:feature-list-of vegetasi [ x ->
    ask patches gis:intersecting x [
      set vegetasipatch gis:property-value x "Def_new"

      if vegetasipatch = "Water" [set pcolor 104]
      if vegetasipatch = "Oil palm"[set pcolor 47]
      if vegetasipatch = "Soil" [set pcolor 37]
      if vegetasipatch = "Swamp"[set pcolor 94]
      if vegetasipatch = "Swamp forest"[set pcolor 84]
      if vegetasipatch = "Logged-over swamp forest"[set pcolor 82]
      if vegetasipatch = "Secondary swamp forest"[set  pcolor 85]

      if vegetasipatch = "Forest"    [
        set pcolor 64
        set class "forest"
        set vegetation 20 + random 21
        set fallowlength vegetation
        set fertility fallowlength + 1
        if fertility > 12 [set fertility 12]
        set patch_basal 3.75
        set patch_alpha 50.487
        set patch_density 81
        set biomass 36.7
        set bird_richness 81
        set patch_tree_richness 91
      ]
      if  vegetasipatch = "Secondary forest"  or vegetasipatch = "Logged-over forest" or vegetasipatch = "Depleted forest"  [
        set pcolor 64
        set class "secondaryforest"
        set vegetation 20 + random 21
        set fallowlength vegetation
        set fertility fallowlength + 1
        if fertility > 12 [set fertility 12]
        set patch_basal 3.53
        set patch_alpha 35.3
        set patch_density 96
        set biomass 7.4335
        set bird_richness 68
        set patch_tree_richness 85
      ]

      if vegetasipatch = "Swidden field" or vegetasipatch = "Paddy field" or vegetasipatch = "Grassland, Fernland"[
        set class "youngfallow"
        set vegetation 2 + random 9
        set fallowlength vegetation
        set fertility fallowlength + 1
        if fertility > 12 [set fertility 12]
        set patch_basal 0.00
        set patch_alpha 0
        set patch_density 0
        set pcolor 68
        set biomass 0.00
        set bird_richness 1
        set patch_tree_richness 0
      ]

      if vegetasipatch = "Old fallow secondary" or vegetasipatch = "Old fallow secondary forest" or vegetasipatch = "Rubber with secondary forest"[
        set pcolor 66
        set class "oldfallow"
        set vegetation 10 + random 11
        set fallowlength vegetation
        set fertility fallowlength + 1
        if fertility > 12 [set fertility 12]
        set patch_basal 0.75
        set patch_alpha 18.38
        set patch_density 67.5
        set biomass 0.8119
        set bird_richness 69
        set patch_tree_richness 39
      ]

      if vegetasipatch = "Young fallow" or vegetasipatch = "Young fallow secondary forest"[
        set pcolor 68
        set class "youngfallow"
        set vegetation 2 + random 9
        set fallowlength vegetation
        set fertility fallowlength + 1
        if fertility > 12 [set fertility 12]
        set patch_basal 0.25
        set patch_alpha 10.91
        set patch_density 48.5
        set biomass 0.2
        set bird_richness 57
        set patch_tree_richness 25
      ]
    ]
  ]

  ask patches [
    set rubber 0
    set illipe 0
    if vegetation > 30 [set vegetation 30]
  ]

  ask patches [set nationalpark 0]
  foreach gis:feature-list-of danau [ x ->
    ask patches gis:intersecting x [
      set pcolor 135
      set nationalpark 1]
  ]
  foreach gis:feature-list-of betung [ x ->
    ask patches gis:intersecting x [
      set pcolor 135
      set nationalpark 1]
  ]

  ask patches [set river 0 set riverprox 0]
  foreach gis:feature-list-of rivers [ x ->
    ask patches gis:intersecting x [
      set river 1
      ask patches in-radius river-prox
      [set riverprox 1 ]
    ]
  ]

  ask patches [set vegetasivali 1
    if (vegetasipatch = "Water" or  vegetasipatch = "Oil palm" or vegetasipatch = "Swamp" or  vegetasipatch = "Secondary swamp forest" or  vegetasipatch = "Swamp forest" or  vegetasipatch = "Logged-over swamp forest" or  vegetasipatch = "Soil" or vegetasipatch = 0 or nationalpark = 1)
    [set vegetasivali  0]
  ]
end


to setup-farmers
  ask turtles [die]
  file-close-all
  file-open "data/netlogo_alldatawide2.csv"
  let headings csv:from-row file-read-line
  while [ not file-at-end? ] [
    let data csv:from-row file-read-line
    create-turtles 1 [
      set HHID item 0 data
      set ycor item 1 data
      set xcor item 2 data
      set initial-laborforce item 3 data
      set initial-laborforce initial-laborforce * 365
      set iEnergyRequirement item 3 data
      set plots_cultivated item 4 data
      set Farmsize item 5 data
      set NumberPlots item 7 data
      if Numberplots = "" [set NumberPlots 0]
      set shape "turtle"
      set size 1
      set color magenta
    ]
  ]
  file-close-all
end


to setup-farms
  set probsecondrice 12.5
  set probrubber 76
  ask patches [set owner ""]
  file-close-all
  file-open "data/netlogo_plotdatalong2.csv"
  let headings csv:from-row file-read-line
  while [ not file-at-end? ] [
    let data csv:from-row file-read-line
    let identify item 0 data
    ask turtles with [hhid = identify]
    [
      let candidates 0
      set candidates patches with [ owner = "" and vegetasivali = 1 and nationalpark != 1  and vegetasipatch != "Water"]
      let plotzero 0
      ifelse any? candidates in-radius livelihood-radius
      [set plotzero one-of candidates in-radius livelihood-radius ]
      [set plotzero min-one-of candidates [distance myself]]

      ask plotzero
        [
          set owner [HHID] of myself
          if probsecondrice > random 100 [set illipe 0 set rubber 0 set class "riceweeds" set vegetation 1 set patch_basal 0 set patch_alpha 0 set patch_density 0  set biomass 0 set bird_richness 1 set patch_tree_richness 0 set fertility ((random 11) + 2) set fallowlength 1]
          set plotid item 2 data
          let plotsizetotal item 6 data
          if plotsizetotal  = 0 [set plotsizetotal 10]
          let plotswithid 1
          while [plotswithid < plotsizetotal ]
          [ask one-of patches with [owner = [owner] of myself and plotid =  [plotid] of myself ]
            [ask min-one-of patches with [class != 0 and owner = "" and  nationalpark != 1 and vegetasipatch != "Water"][distance myself]
              [
                set owner [owner] of myself
                set plotid [plotid] of myself
                set plotswithid plotswithid + 1
              ]
            ]
          ]

          ask patches with [owner = [owner] of myself and plotid = [plotid] of myself]
          [
            set illipe 0
            set rubber 0
            set class [class] of myself
            set fertility [fertility] of myself
            set fallowlength [fallowlength] of myself
            set vegetation [vegetation] of myself
            set patch_basal [patch_basal] of myself
            set patch_alpha [patch_alpha] of myself
            set patch_density [patch_density] of myself
            set biomass [biomass] of myself
            set bird_richness [bird_richness] of myself
            set patch_tree_richness [patch_tree_richness] of myself
          ]
      ]
      if max-plotid < item 2 data [set max-plotid item 2 data]
      set max-plotid max-plotid + 1
    ]
  ]
  file-close-all

  ask turtles [
    set my-plots patches with [owner = [hhid] of myself]
    ifelse any? my-plots with [class != "riceweeds" and class != "rice"]
    [set fallow-plots my-plots with [class != "riceweeds" and class != "rice"]
      ask one-of fallow-plots [if probrubber > random 100 [
        set rubber 1 + random 24
        set class "rubber"
        set patch_basal 2
        set patch_alpha 25.48
        set patch_density 54.7
        set biomass 9.8
        set bird_richness  49
        set patch_tree_richness  69
        ask patches with [owner = [owner] of myself and plotid = [plotid] of myself] [
          set rubber [rubber] of myself
          set patch_basal 2
          set patch_alpha 25.48
          set patch_density 54.7
          set biomass 9.8
          set bird_richness  49
          set patch_tree_richness  69
          set class "rubber"
        ]
        ]
      ]
    ]
    [set fallow-plots 0]
  ]
end



to setup-globals
  ; / 10 because the input is on a hectar level but here the plots are 0.1 * 1 hectare;

  set work-for-processing 20 / 10

  ;set secondrice 0.5
  set fatshare 0.2

  set ricecalories 1650
  set pricerice 10000
  set pricerubber 6500
  set rubbercalories 1070
  set rubbercalories ricecalories * pricerubber / pricerice

  set illiperubberyieldi [ 0 0 0 0 0 0 0 0 360 0 0 0 380 0 0 0 400 0 0 0 420 0 0 0 500 0 0 0 570 0 0 0 650 0 0 0 700 0 0 0 700 0 0 0 700 0 0 0 700 0 0 0 650 0 0 0 650 0 0 0 500 0 0 0 500 0 0 0 400 0 0 0 400 0 0 0 325 0 0 0 325 0 0 0 325 0 0 0 325 0 0 0 300 0 0 0 300 ]
  set illiperubberyieldr [0 0 0 0 0 8 8 8 9.3 9.3 9.3 11.6 11.6 11.6 11.5 11.5  8.5 8.5 5.3 5.3 5.3 2 2 2 2 2 ]
  set rubberyield [0 0 0 0 0 13.75 13.75 13.75 20 20 20 24 24 24 24 24 17.5 17.5 11.6 11.6 11.6 5 5 5 5 5]

  set illipecalories ricecalories * price-illipe / pricerice
  set yieldfat ricecalories * price-processed-illipe / pricerice

  set yieldfactor 0.42

  if scenario = "baseline"    [set ricefactor (1)]
  if scenario = "0.5" [set ricefactor (1 - 0.051)]
  if scenario = "1"   [set ricefactor (1 - 0.088)]
  if scenario = "1.5" [set ricefactor (1 - 0.126)]
  if scenario = "2"   [set ricefactor (1 - 0.162)]
  if scenario = "2.5" [set ricefactor (1 - 0.195)]
  if scenario = "3"   [set ricefactor (1 - 0.228)]

  let potential_fixation (count patches with [vegetasivali = 1] ) * 36.7
  let actual_fixation ((count patches with [vegetasivali = 1 and class = "rice" and rubber = 0] ) * 0 ) + ((count patches with [vegetasivali = 1 and class = "riceweeds" and rubber = 0]) * 0.00) + ((count patches with [vegetasivali = 1 and class = "secondaryforest" and rubber = 0] ) * 7.4335) + ((count patches with [vegetasivali = 1 and class = "oldfallow" and rubber = 0]) * 0.8119) + ((count patches with [vegetasivali = 1 and class = "youngfallow" and rubber = 0]) * 0.2) + ((count patches with [illipe > 0 and vegetasivali = 1]) * 13) + ((count patches with [illipe = 0 and rubber > 0 and vegetasivali = 1]) * 9.8 )
  set carbon_lost (potential_fixation - actual_fixation ) / potential_fixation
end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go
  reset-timer
  if ticks = 60 [stop]

  ask turtles [
    calculate-energy-requirement
    work-and-harvest-from-riceweeds
    if illipe? = true [ work-and-harvest-from-illiperubber  ]

    livelihood-decision
    harvest
  ]

  update-farmers-and-globals
  if charting? = true [chart]
  vegetation-transition
  tick
  show timer
end

to calculate-energy-requirement
  set EnergyRequirement iEnergyRequirement * 1936 * 365

  set available-laborforce initial-laborforce
  set Energyconsumption 0 set Riceconsumption 0 set Rubberincome 0 set IllipeAFincome 0 set rubberAFincome 0 set AFincome 0 set Illipeharvest 0 set IllipeincomeProcessed 0
  set aEnergyconsumption 0 set aRiceconsumption 0 set aRubberincome 0 set aIllipeAFincome 0 set arubberAFincome 0 set aAFincome 0 set aIllipeincomeProcessed 0
  set income 0
  set RubberFarmer 0
  set RiceFarmer 0
  set IllipeFarmer 0
  set IllipeProcessor 0
  set food-insecure 0
  set deficit 0

  set my-plots patches with [owner = [hhid] of myself]
  set fallow-plots (my-plots with [ class != "rice" and class != "riceweeds" and rubber = 0 and illipe = 0 ])
end



to work-and-harvest-from-riceweeds
  ;harvest and work from rice
  let my-rice-plots my-plots with [class = "riceweeds"]
  ask my-rice-plots [
    set yield ( yieldfactor * ricefactor * (ricecalories / 10 ) * 1866 / ( 1 + 8.07 * exp ( - 0.52 * fertility)))
  ]
  let riweed count my-plots with [class = "riceweeds"]
  let harvestriceweeds (secondrice * (sum [yield] of my-rice-plots ) )
  set available-laborforce available-laborforce - (riweed * 43 * secondrice / 10)

  set Energyconsumption (Energyconsumption + harvestriceweeds)
  set Riceconsumption (Riceconsumption + harvestriceweeds)
  if any? my-rice-plots [set RiceFarmer 1]
end


to  work-and-harvest-from-illiperubber
  ;work from illiperuber
  if any? my-plots with [illipe > 0][
    set IllipeFarmer 1
    let laborillipe 0
    let laborrubber 0
    set laborrubber laborrubber + (count my-plots with [illipe > 0 and rubber > 1 and rubber < 6] ) * 0.5 * 26 / 10
    set laborrubber laborrubber + (count my-plots with [illipe > 0 and rubber > 5 ] ) * 0.5 * 73 / 10
    set laborillipe  laborillipe + ((count my-plots with [illipe > 0 and ticks mod 4 != 0] ) * 26 / 10)
    set laborillipe  laborillipe + ((count my-plots with [illipe > 7 and ticks mod 4 = 0 ]) * 73 / 10)
    set available-laborforce available-laborforce - laborillipe - laborrubber

    ;harvest from illiperubberAF
    let sumilliperubberi 0
    let sumilliperubberr 0
    ask my-plots with [illipe > 7 and (ticks mod 4 = 0)][
      let illipey item illipe illiperubberyieldi
      set sumilliperubberi sumilliperubberi + illipey
    ]
    set Illipeharvest sumilliperubberi

    ask my-plots with [illipe > 0 and rubber > 5 and rubber < 26][
      let rubbery item rubber illiperubberyieldr
      set sumilliperubberr sumilliperubberr + rubbery
    ]

    let sr sumilliperubberr * rubbercalories
    let si sumilliperubberi * illipecalories
    set Energyconsumption Energyconsumption + sr
    set Energyconsumption Energyconsumption + si
    set rubberAFincome rubberAFincome + sr
    set IllipeAFincome IllipeAFincome + si
    set AFincome AFincome + (IllipeAFincome + rubberAFincome)
  ]
end

to livelihood-decision

  cultivate-rice

  if available-laborforce > 0 [work-from-rubber]
  if available-laborforce > 0 [harvest-from-rubber]

  if available-laborforce > 0 [rubber-illipe]

  if (Illipeharvest > 0 and illipeprocessing? = true and available-laborforce > 0  ) [process-illipe]
end


to cultivate-rice
  let i  0
  let aux 0

  while [Energyconsumption < EnergyRequirement]
  [
    ifelse any? fallow-plots
    [
      cultivate-own-plot
    ]
    [
      slash-and-burn
      set aux 1
      set i i + 1
      if i = 40 [

        set deficit ( deficit +  (EnergyRequirement - Energyconsumption))
        set Energyconsumption  Energyconsumption + deficit

      ]
    ]
  ]

  if aux > 0 [ set max-plotid max-plotid + 1]
end

to cultivate-own-plot
  let a 0
  let b 0
  ask max-one-of fallow-plots with [rubber = 0] [fertility][
    ask patches with [owner = [owner] of myself and plotid = [plotid] of myself ][

      if fertility > 12 [set fertility 12]
      set yield ( yieldfactor * ricefactor *  (ricecalories / 10 ) * 1866 / ( 1 + 8.07 * exp ( - 0.52 * fertility)))

      set a a + yield
      set b b + 43 / 10
      set class "rice"
      set vegetation 1 set patch_basal 0 set patch_alpha 0 set patch_density 0  set biomass 0 set bird_richness 1 set patch_tree_richness 0
      set fertility fallowlength + 1 set fallowlength 0
    ]
  ]
  set RiceFarmer 1
  set Energyconsumption Energyconsumption + a
  set Riceconsumption Riceconsumption + a
  set available-laborforce available-laborforce - b
  if available-laborforce < 0 and EnergyRequirement > Energyconsumption [

    set deficit (deficit + (EnergyRequirement - Energyconsumption) )
    set Energyconsumption Energyconsumption + deficit
  ]
end


to slash-and-burn
  let c 0
  let d 0
  let candidate 0
  if ticks > 0 and any?  my-plots with [plotid = [max-plotid] of myself]
  [
    ask one-of my-plots with [ plotid = [max-plotid] of myself][
      if any? neighbors with [vegetasivali = 1 and owner = "" and class != "rice" and class != "riceweeds" and rubber = 0 and vegetasipatch != "Water"]
      [
        set candidate one-of neighbors with [vegetasivali = 1 and owner = "" and class != "rice" and class != "riceweeds" and rubber = 0 and vegetasipatch != "Water"]
      ]
    ]
  ]
  if candidate = 0
  [

    if any? patches with [vegetasivali = 1 and owner = "" and class != "rice" and class != "riceweeds" and rubber = 0 and vegetasipatch != "Water"] in-radius 100
    [set candidate  min-one-of patches with [vegetasivali = 1 and owner = "" and class != "rice" and class != "riceweeds" and rubber = 0 and vegetasipatch != "Water" ] in-radius 100 [distance myself]]
  ]
  if candidate != 0
  [
    ask candidate [
      set owner  [hhid] of myself
      set plotid [max-plotid] of myself
      if fertility > 12 [set fertility 12] set yield ( yieldfactor * ricefactor * (ricecalories / 10 ) * 1866 / ( 1 + 8.07 * exp ( - 0.52 * fertility)))

      set c c + yield
      set d d + 43 / 10
      set class "rice"
      set vegetation 1 set patch_basal 0 set patch_alpha 0 set patch_density 0  set biomass 0 set bird_richness 1 set patch_tree_richness 0
      set fertility fallowlength + 1 set fallowlength 0
    ]
    set Energyconsumption Energyconsumption + c
    set Riceconsumption Riceconsumption + c
    set RiceFarmer 1
    set available-laborforce available-laborforce - d
  ]

  if candidate = 0 [
    if EnergyRequirement > Energyconsumption [
      set deficit (deficit + (EnergyRequirement - Energyconsumption))
      set Energyconsumption Energyconsumption + deficit
    ]
  ]
  set my-plots patches with [owner = [hhid] of myself]
  set NumberPlots max [plotid] of my-plots
end

to work-from-rubber
  let laborrubber 0
  set laborrubber (laborrubber + ((count my-plots with [illipe = 0 and rubber > 1 and rubber < 6] ) * 26 / 10))
  set available-laborforce (available-laborforce -  laborrubber)
end


to harvest-from-rubber
  let laborrubber 0
  set laborrubber (laborrubber + ((count my-plots with [illipe = 0 and rubber > 5 ] ) * 73 / 10))
  set available-laborforce (available-laborforce -  laborrubber)

  let sumrubber 0

  ask my-plots with [rubber > 5 and illipe = 0][
    let rubbery item rubber rubberyield
    set sumrubber ( sumrubber + rubbery )
  ]
  set Energyconsumption Energyconsumption + sumrubber * rubbercalories
  set Rubberincome Rubberincome + sumrubber * rubbercalories
  set RubberFarmer 1
end

to rubber-illipe
  ifelse illipe? = true
  [
    plant-illipe-or-rubber
  ][
    plant-rubber
  ]
end

to plant-illipe-or-rubber
  let workili 0
  let river-plots fallow-plots with [riverprox = 1 ]
  ifelse any? river-plots
  [
    ask one-of river-plots
    [set rubber 1 set illipe 1
      set patch_basal 2.7
      set patch_alpha 39.74
      set patch_density 132
      set biomass 13
      set bird_richness 60
      set patch_tree_richness 60
      set class "illipe"
      set workili workili + 1
      ask other patches with [owner = [owner] of myself and plotid = [plotid] of myself] [
        set illipe 1 set rubber 1 set workili workili + 1
        set patch_basal 2.7
        set patch_alpha 39.74
        set patch_density 132
        set biomass 13
        set bird_richness 60
        set patch_tree_richness 60
        set class "illipe"
      ]
      ask myself [
        set illipeFarmer 1 set available-laborforce  available-laborforce - (workili * 52 * 1.5 / 10 )

      ]
    ]
  ]
  [
    plant-rubber
  ]
end


to plant-rubber
  let workrub 0

  set plots_rubber count my-plots with [rubber > 0]
  if plots_rubber < 12 and any? fallow-plots with [rubber = 0]
  [
    ask one-of fallow-plots with [rubber = 0]
    [
      set rubber 1
      set workrub 1
      set patch_basal 2
      set patch_alpha 25.48
      set patch_density 54.7
      set biomass 9.8
      set bird_richness  49
      set patch_tree_richness  69
      set class "rubber"
      ask other patches with [owner = [owner] of myself and plotid = [plotid] of myself ] [
        set rubber 1
        set workrub workrub + 1
        set patch_basal 2
        set patch_alpha 25.48
        set patch_density 54.7
        set biomass 9.8
        set bird_richness  49
        set patch_tree_richness  69
        set class "rubber"
      ]
      ask myself [
        set RubberFarmer 1
        set available-laborforce  available-laborforce - ( workrub * 52 / 10 )
      ]
    ]
  ]
end


to process-illipe
  set available-laborforce available-laborforce - work-for-processing * Illipeharvest
  set IllipeProcessor 1
  set Energyconsumption Energyconsumption - IllipeAFincome
  set IllipeAFincome 0
  set yieldfat  Illipeharvest * fatshare
  set yieldfat yieldfat * ricecalories * price-processed-illipe / pricerice
  set Energyconsumption Energyconsumption +  yieldfat
  set IllipeincomeProcessed IllipeincomeProcessed + yieldfat
  set AFincome AFincome + yieldfat
end


to harvest
  set aEnergyconsumption (Riceconsumption + Rubberincome + IllipeAFincome + RubberAFincome + IllipeincomeProcessed)
  set aRiceconsumption Riceconsumption
  set aRubberincome Rubberincome
  set aIllipeAFincome IllipeAFincome
  set aAFincome AFincome
  set arubberAFincome rubberAFincome
  set aIllipeincomeProcessed IllipeincomeProcessed
  let totalfoodintake (aRiceconsumption + aRubberincome + aAFincome + aIllipeincomeProcessed)
  if EnergyRequirement > (totalfoodintake - deficit)[set food-insecure 1     ]
  set income (Rubberincome + IllipeAFincome + RubberAFincome + IllipeincomeProcessed)
end



to update-farmers-and-globals
  ask turtles [
    set my-plots patches with [owner = [hhid] of myself]
    set fallow-plots (my-plots with [ class != "rice" and class != "riceweeds" and rubber = 0])
    set NumberPlots max [plotid] of my-plots
    set Farmsize (count my-plots)

    let q 1
    set plots_cultivated 0 set plots_rice 0 set plots_rubber 0 set plots_AF 0
    while [q < NumberPlots + 1]
    [
      let help 0
      if any? my-plots with [plotid = q]
      [
        ask one-of my-plots with [plotid = q ] [
          if class = "rice" or class = "riceweeds"
          [ ask myself [
            set help 1
            set RiceFarmer 1
            set plots_rice plots_rice + 1
            ]
          ]
          if rubber > 0 and illipe = 0
          [
            ask myself [
              set help 1
              set RubberFarmer 1
              set plots_rubber plots_rubber + 1
            ]
          ]
          if illipe > 0
          [ ask myself
            [
              set help 1
              set  Illipefarmer 1
              set plots_AF plots_AF + 1
            ]
          ]
        ]
      ]
      set plots_cultivated plots_cultivated + help
      set q q + 1
    ]

    set iarea_cultivated (count my-plots with [class = "rice" or class = "riceweeds" or rubber > 0])
    set ishare-illipe (( count my-plots with [illipe > 0 ] ) / ( count my-plots))
  ]

  set food-insecure-households ( count turtles with [food-insecure = 1])
  set new-plots count patches with [owner != ""]

  set area_cultivated (sum [iarea_cultivated] of turtles)
  set share-illipe ( mean [ishare-illipe] of turtles)
  set mean_plots_rubber ( mean [plots_rubber] of turtles)
  set mean_plots_cultivated ( mean [plots_cultivated] of turtles)
  set mean_plots_AF ( mean [plots_AF] of turtles)
  set mean_plots_rice ( mean [plots_rice] of turtles)

  ;patches
  set ricepatches count patches with [class = "rice"]
  set riceweedpatches count patches with [class = "riceweeds"]
  set youngfallowpatches count patches with [class = "youngfallow"]
  set oldfallowpatches count patches with [class = "oldfallow"]
  set secondaryforestpatches count patches with [class = "secondaryforest"]
  set illipepatches count patches with [illipe > 0]
  set rubberpatches count patches with [rubber > 0 and illipe = 0]
  set forestpatches count patches with [class = "forest"]

  ; biodiversity indicators
  set mean_basal mean [patch_basal] of patches
  set mean_alpha  mean [patch_alpha] of patches
  set mean_density mean [patch_density] of patches
  set mean_biomass mean [biomass] of patches
  set mean_bird_richness mean [bird_richness] of patches
  set mean_patch_tree_richness mean [patch_tree_richness] of patches
  ;carbon sequestration
  set carbon_patch mean [biomass] of patches
  set carbon_ha carbon_patch * 10

  if any? patches with [owner != "" and owner != 9999 ] [ set  mean_fertility  mean [fertility] of patches with [owner != "" and owner != 9999 ]]
  if any? patches with [owner != "" and owner != 9999 and class = "rice"] [set mean_rice_fertility  mean [fertility] of patches with [owner != "" and owner != 9999 and class = "rice"]]

  ;livelihoods chosen
  set Ricefarmers (( count turtles with [RiceFarmer = 1] ) * 100 / ( count turtles ))
  set Rubberfarmers ( (count turtles with [RubberFarmer = 1 ]) * 100 / (count turtles ) )
  set Illipefarmers (( count turtles with [IllipeFarmer = 1] ) * 100 / (count turtles ) )
  set Illipeprocessors (( count turtles with [IllipeProcessor = 1] ) * 100 / ( count turtles ) )

  ;caloric consumptions
  set mean_energyconsumption mean [aEnergyconsumption * 100 / Energyrequirement] of turtles
  set mean_riceconsumption mean [aRiceconsumption * 100 / Energyrequirement] of turtles

  set amean_energyconsumption mean [aEnergyconsumption ] of turtles
  set amean_riceconsumption mean [aRiceconsumption ] of turtles

  ;Incomes in Mio IDR
  set mean_rubberincome mean [(aRubberincome * 10000 / 1650 ) / 1000000] of turtles
  set mean_illipeAFincome mean [( aIllipeAFincome * 10000 / 1650 ) / 1000000] of turtles
  set mean_rubberAFincome mean [(arubberAFincome * 10000 / 1650 ) / 1000000] of turtles
  set mean_AFincome mean [(aAFincome * 10000 / 1650 ) / 1000000] of turtles
  set mean_illipeprocessedincome mean [(aIllipeincomeProcessed * 10000 / 1650 ) / 1000000] of turtles

  set mean_income mean [(income * 10000 / 1650 ) / 1000000] of turtles

  ;patches visualization
  ask patches with [vegetasivali = 1 and nationalpark = 0] [
    if class = "rice" [set pcolor 47]
    if class = "riceweeds" [set pcolor 27]
    if class = "youngfallow" [set pcolor cyan]
    if class = "oldfallow" [set pcolor sky]
    if class = "secondaryforest" [set pcolor green]
    if rubber > 0 and illipe = 0 [set pcolor 117]
    if illipe > 0 [set pcolor 125]
    if owner = 9999 [set pcolor 68]
  ]

  ;carbon
  let potential_fixation (count patches with [vegetasivali = 1] ) * 36.7
  let actual_fixation ((count patches with [vegetasivali = 1 and class = "rice" and rubber = 0] ) * 0 ) + ((count patches with [vegetasivali = 1 and class = "riceweeds" and rubber = 0]) * 0.00) + ((count patches with [vegetasivali = 1 and class = "secondaryforest" and rubber = 0] ) * 7.4335) + ((count patches with [vegetasivali = 1 and class = "oldfallow" and rubber = 0]) * 0.8119) + ((count patches with [vegetasivali = 1 and class = "youngfallow" and rubber = 0]) * 0.2) + ((count patches with [illipe > 0 and vegetasivali = 1]) * 13) + ((count patches with [illipe = 0 and rubber > 0 and vegetasivali = 1 ]) * 9.8 )
  set carbon_lost (potential_fixation - actual_fixation ) * 100 / potential_fixation
end



to chart
  ; land cover
  set-current-plot "land cover"
  set-current-plot-pen "rice cultivation"
  plot ricepatches
  set-current-plot-pen "rice and weeds"
  plot riceweedpatches
  set-current-plot-pen "young fallow"
  plot youngfallowpatches
  set-current-plot-pen "old fallow"
  plot oldfallowpatches
  set-current-plot-pen "secondary forest"
  plot secondaryforestpatches
  set-current-plot-pen "illiperubberAF"
  plot illipepatches
  set-current-plot-pen "rubber"
  plot rubberpatches

  ; biodiversity indicators
  set-current-plot "Biodiversity indicators"
  set-current-plot-pen "basal area"
  plot mean_basal
  set-current-plot-pen "fisher's alpha"
  plot  mean_alpha
  set-current-plot-pen "density"
  plot mean_density / 10
  set-current-plot-pen "biomass"
  plot mean_biomass
  set-current-plot-pen "bird richness"
  plot mean_bird_richness
  set-current-plot-pen "tree richness"
  plot mean_patch_tree_richness

  set-current-plot "Livelihoods chosen"
  set-current-plot-pen "Rice"
  plot Ricefarmers
  set-current-plot-pen "Rubber"
  plot Rubberfarmers
  set-current-plot-pen "Illipe"
  plot Illipefarmers
  set-current-plot-pen "IllipeProcessor"
  plot Illipeprocessors

  set-current-plot "Income"
  set-current-plot-pen "Rubber"
  plot mean_rubberincome
  set-current-plot-pen "IllipeAF"
  plot mean_illipeAFincome
  set-current-plot-pen "RubberAF"
  plot mean_rubberAFincome
  set-current-plot-pen "totalAF"
  plot mean_AFincome
  set-current-plot-pen "IllipeProcessed"
  plot mean_illipeprocessedincome

  ;carbon sequestration
  set-current-plot "Carbon sequestration"
  set-current-plot-pen "carbon per ha"
  plot carbon_ha
end

to vegetation-transition
  ask patches with [vegetasivali = 1][
    set vegetation vegetation + 1
    if vegetation > 30 [set vegetation 30 ]
    set fallowlength fallowlength + 1

    if fallowlength < 11 and fallowlength > 1  and rubber = 0 and class != "rubber" [set class "youngfallow"     set yield 0]
    if fallowlength > 10 and fallowlength < 21 and rubber = 0 and class != "rubber" [set class "oldfallow"       set yield 0]
    if fallowlength > 20                       and rubber = 0 and class != "rubber" [set class "secondaryforest" set yield 0]
  ]

  ask patches with [class = "riceweeds" and rubber = 0][set class "youngfallow" ]
  ask patches with [class = "rice" and rubber = 0]     [set class "riceweeds"]

  ask patches [
    if class != "rice" and class != "riceweeds" [set fertility fallowlength + 1]
    if fertility > 10 [set fertility 10]
  ]

  ask patches [
    if class = "rubber"  [
      set rubber rubber + 1
      set patch_basal 2
      set patch_alpha 25.48
      set patch_density 54.7
      set biomass 9.8
      set bird_richness  49
      set patch_tree_richness  69
      if rubber = 25 [set rubber 0 set biomass 0 set class "oldfallow"]
    ]
    if class = "illipe" [
      set illipe illipe + 1
      set rubber rubber + 1
      set patch_basal 2.7
      set patch_alpha 39.74
      set patch_density 132
      set biomass 13
      set bird_richness 60
      set patch_tree_richness 60
      if illipe = 96 [set illipe 0 set biomass 0 set class "secondaryforest"]
      if rubber = 25 [set rubber 1]
    ]

    if class = "youngfallow"      [set patch_basal 0.25 set patch_alpha 10.91 set patch_density 48.5   set biomass 0.2    set bird_richness 57 set patch_tree_richness 25]
    if class = "oldfallow"        [set patch_basal 0.75 set patch_alpha 18.38 set patch_density 67.5   set biomass 0.8119 set bird_richness 69 set patch_tree_richness 39]
    if class = "secondaryforest"  [set patch_basal 3.53 set patch_alpha 35.3  set patch_density 96     set biomass 7.4335 set bird_richness 68 set patch_tree_richness 85]
    if class = "rice"             [set vegetation 1 set patch_basal 0   set patch_alpha 0 set patch_density 0  set biomass 0    set bird_richness 1 set patch_tree_richness 0]
    if class = "riceweeds"        [set vegetation 1 set patch_basal 0   set patch_alpha 0 set patch_density 0  set biomass 0.0 set bird_richness 1 set patch_tree_richness 0]
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
1058
1336
-1
-1
3.0
1
10
1
1
1
0
0
0
1
-128
151
-165
273
1
1
1
ticks
30.0

BUTTON
8
684
201
718
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
4
774
201
807
illipe?
illipe?
1
1
-1000

SLIDER
4
809
200
842
price-illipe
price-illipe
1000
20000
7000.0
1
1
NIL
HORIZONTAL

PLOT
1062
734
1436
884
Land cover
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"rice cultivation" 1.0 0 -1184463 true "" ""
"rice and weeds" 1.0 0 -817084 true "" ""
"young fallow" 1.0 0 -13345367 true "" ""
"old fallow" 1.0 0 -8330359 true "" ""
"secondary forest" 1.0 0 -15637942 true "" ""
"illiperubberAF" 1.0 0 -10141563 true "" ""
"rubber" 1.0 0 -11053225 true "" ""

PLOT
1063
887
1437
1037
Biodiversity indicators
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"basal area" 1.0 0 -13345367 true "" ""
"fisher's alpha" 1.0 0 -7858858 true "" ""
"density" 1.0 0 -14439633 true "" ""
"bird richness" 1.0 0 -1184463 true "" ""
"biomass" 1.0 0 -955883 true "" ""
"tree richness" 1.0 0 -7500403 true "" ""

PLOT
1062
415
1436
565
Livelihoods chosen
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Rice" 1.0 0 -1184463 true "" ""
"Rubber" 1.0 0 -9276814 true "" ""
"Illipe" 1.0 0 -2674135 true "" ""
"IllipeProcessor" 1.0 0 -11221820 true "" ""

PLOT
1062
563
1436
732
Income
NIL
in Mio IDR
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Rubber" 1.0 0 -7500403 true "" ""
"IllipeAF" 1.0 0 -2674135 true "" ""
"IllipeProcessed" 1.0 0 -11221820 true "" ""
"RubberAF" 1.0 0 -955883 true "" ""
"totalAF" 1.0 0 -10141563 true "" ""

BUTTON
34
1000
148
1033
NIL
go
NIL
1
T
OBSERVER
NIL
G
NIL
NIL
1

BUTTON
34
1035
148
1068
NIL
go
T
1
T
OBSERVER
NIL
F
NIL
NIL
1

SWITCH
4
845
201
878
illipeprocessing?
illipeprocessing?
0
1
-1000

SLIDER
4
882
201
915
price-processed-illipe
price-processed-illipe
10000
500000
100000.0
1
1
NIL
HORIZONTAL

SLIDER
3
918
201
951
yields-illipe
yields-illipe
750
2000
2000.0
50
1
NIL
HORIZONTAL

SLIDER
4
739
201
772
river-prox
river-prox
0
15
7.0
1
1
NIL
HORIZONTAL

TEXTBOX
1079
354
1329
414
yellow:     rice\norange:    rice + weed\npurple:     rubber\nmagenta: illipe rubber agroforestry
11
0.0
1

SLIDER
8
649
200
682
yieldfactor
yieldfactor
0
1
0.42
0.02
1
NIL
HORIZONTAL

PLOT
1064
1039
1438
1189
Carbon sequestration
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"carbon per ha" 1.0 0 -16777216 true "" ""

SLIDER
8
614
200
647
livelihood-radius
livelihood-radius
0
150
60.0
1
1
NIL
HORIZONTAL

SLIDER
8
579
200
612
secondrice
secondrice
0
1
0.5
0.1
1
NIL
HORIZONTAL

CHOOSER
8
532
200
577
scenario
scenario
"baseline" "0.5" "1" "1.5" "2" "2.5" "3"
0

SWITCH
7
497
198
530
charting?
charting?
0
1
-1000

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
